@@ -8,8 +8,8 @@ OC.L10N.register(
     "Rename" : "Nimeta ümber",
     "Send email" : "Saada kiri",
     "Delete" : "Kustuta",
-    "Download" : "Lae alla",
     "Copy link" : "Kopeeri link",
+    "Download" : "Lae alla",
     "_%n contact_::_%n contacts_" : ["%n kontakt","%nkontakti"],
     "_%n group_::_%n groups_" : ["%n grupp","%n gruppi"],
     "Share with users or groups" : "Jaga kasutajate või gruppidega",
@@ -25,11 +25,11 @@ OC.L10N.register(
     "Description" : "Kirjeldus",
     "Settings" : "Settings",
     "Cancel" : "Loobu",
-    "Delete picture" : "Kustuta pilt",
     "Invalid image" : "Vigane pilt",
+    "Delete picture" : "Kustuta pilt",
+    "Address book" : "Aadressiraamat",
     "Name" : "Nimi",
     "Title" : "Pealkiri",
-    "Address book" : "Aadressiraamat",
     "Search contacts …" : "Otsi kontakte",
     "No results" : "Vasteid ei leitud",
     "Pending" : "Ootel",
@@ -78,7 +78,6 @@ OC.L10N.register(
     "Voice" : "Hääl",
     "Car" : "Auto",
     "Work pager" : "Piipar (tööl)",
-    "Manager" : "Juht",
     "Social network" : "Sotsiaalvõrk",
     "Spouse" : "Abikaasa",
     "Child" : "Laps",
@@ -94,6 +93,7 @@ OC.L10N.register(
     "Gender" : "Sugu",
     "Female" : "Naine",
     "Male" : "Mees",
-    "Unknown" : "Teadmata"
+    "Unknown" : "Teadmata",
+    "Manager" : "Juht"
 },
 "nplurals=2; plural=(n != 1);");
