@@ -27,15 +27,13 @@ OC.L10N.register(
     "Send email" : "이메일 보내기",
     "Send email as BCC" : "BCC로 이메일 보내기",
     "Delete" : "삭제",
-    "Contact groups" : "연락처 그룹",
-    "Create a new contact group" : "새 연락처 그룹 생성",
-    "Contact group name" : "연락처 그룹 이름",
     "Show all groups" : "모든 그룹 보이기",
     "Collapse groups" : "그룹 접기",
     "This group already exists" : "그룹이 이미 존재함",
-    "{addressbookname} (Disabled)" : "{addressbookname} (비활성화됨)",
-    "Download" : "다운로드",
-    "Show" : "보이기",
+    "Contact groups" : "연락처 그룹",
+    "Create a new contact group" : "새 연락처 그룹 생성",
+    "Contact group name" : "연락처 그룹 이름",
+    "_Shared with {num} entity_::_Shared with {num} entities_" : ["{num}명과 공유함"],
     "Copied" : "복사됨",
     "Cannot copy" : "복사할 수 없음",
     "Copy link" : "링크 복사",
@@ -43,23 +41,26 @@ OC.L10N.register(
     "Delete {addressbook}?" : "{addressbook}을(를) 삭제하시겠습니까?",
     "Deletion of address book was not successful." : "주소록 삭제에 실패했습니다.",
     "Renaming of address book was not successful." : "주소록 이름 변경에 실패했습니다.",
+    "{addressbookname} (Disabled)" : "{addressbookname} (비활성화됨)",
+    "Download" : "다운로드",
+    "Show" : "보이기",
     "_%n contact_::_%n contacts_" : ["연락처 %n개"],
     "_%n group_::_%n groups_" : ["그룹 %n개"],
     "Share with users or groups" : "사용자 및 그룹과 공유",
     "Share with users" : "사용자와 공유",
     "No users or groups" : "사용자나 그룹 없음",
-    "can edit" : "편집 가능",
     "Unable to delete the share" : "이 공유를 삭제할 수 없습니다.",
     "Unable to change permissions" : "권한을 변경하지 못했습니다.",
+    "can edit" : "편집 가능",
+    "Choose a vCard file to import" : "불러올 vCard 파일을 고르기",
     "Import contacts" : "연락처 가져오기",
     "Import into the {addressbookName} address book" : "{addressbookName} 주소록에 불러오기",
     "Select local file" : "로컬 파일 선택",
     "Import from files" : "파일로부터 가져오기",
     "Importing is disabled because there are no address books available" : "주소록을 찾을 수 없어서 가져올 수 없습니다.",
-    "Choose a vCard file to import" : "불러올 vCard 파일을 고르기",
+    "An error occurred, unable to create the address book" : "오류가 발생하여 주소록을 생성할 수 없습니다.",
     "Add new address book" : "새 주소록 생성",
     "Add" : "Add",
-    "An error occurred, unable to create the address book" : "오류가 발생하여 주소록을 생성할 수 없습니다.",
     "First name" : "이름",
     "Last name" : "성",
     "Phonetic first name" : "이름 표음",
@@ -73,20 +74,15 @@ OC.L10N.register(
     "Save" : "저장",
     "Change unique password" : "독자 암호 변경",
     "Failed to save password. Please try again later." : "암호를 저장하는 데 실패했습니다. 잠시 후 다시 시도하십시오.",
+    "An error happened during description sync" : "설명 동기화 중 오류 발생",
+    "An error happened during name sync" : "이름 동기화 중 오류 발생",
     "Request to join" : "등록 요청",
     "Description" : "설명",
     "You are not a member of {circle}" : "당신은 {circle}의 회원이 아닙니다.",
     "Settings" : "Settings",
-    "An error happened during description sync" : "설명 동기화 중 오류 발생",
-    "An error happened during name sync" : "이름 동기화 중 오류 발생",
     "Cancel" : "취소",
     "Add more info" : "정보 추가",
     "More fields" : "더 많은 입력란",
-    "Crop contact photo" : "연락처 사진 잘라내기",
-    "Upload a new picture" : "새 그림 업로드",
-    "Choose from Files" : "파일에서 선택",
-    "Download picture" : "그림 다운로드",
-    "Delete picture" : "그림 삭제",
     "Please select a valid format" : "유효한 형식을 선택하십시오",
     "Invalid image" : "잘못된 사진",
     "Error cropping picture" : "연락처 사진을 잘라내던 중 오류 발생",
@@ -95,9 +91,26 @@ OC.L10N.register(
     "Avatar downloaded from social network" : "소셜 네트워크에서 아바타가 다운로드 되었습니다.",
     "Avatar already up to date" : "아바타가 이미 업데이트 되었습니다.",
     "Avatar download failed" : "아바타 다운로드 실패",
+    "Crop contact photo" : "연락처 사진 잘라내기",
+    "Upload a new picture" : "새 그림 업로드",
+    "Choose from Files" : "파일에서 선택",
+    "Download picture" : "그림 다운로드",
+    "Delete picture" : "그림 삭제",
+    "This contact is in read-only mode. You do not have permission to edit this contact." : "이 연락처는 읽기 전용 모드입니다. 편집할 수 있는 권한이 없습니다.",
+    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "편집하려고 하는 연락처가 변경되었습니다. 연락처를 직접 새로 고치십시오. 추가 변경 사항은 손실됩니다.",
+    "Address book" : "주소록",
+    "Add contact to Birthday Calendar" : "연락처를 생일 달력에 추가",
+    "Exclude contact from Birthday Calendar" : "생일 달력에서 연락처 제외",
+    "{title} at {organization}" : "{organization}의 {title}",
+    "Name" : "이름",
+    "Syntax error. Cannot open the contact." : "문법 오류입니다. 연락처를 열 수 없습니다.",
+    "The contact does not exist on the server anymore." : "연락처가 서버에 더 이상 존재하지 않습니다.",
+    "Unable to retrieve the contact from the server, please check your network connection." : "연락처를 가져올 수 없습니다. 네트워크 연결을 확인하세요.",
+    "An error occurred while trying to move the contact" : "연락처를 이동하는 중 오류 발생",
+    "An error occurred while trying to copy the contact" : "연락처를 복사하는 중 오류 발생",
+    "Unable to update contact" : "연락처를 갱신할 수 없음",
     "No contact selected" : "선택한 연락처 없음",
     "Select a contact on the list to begin" : "목록에서 연락처를 선택하여 시작하세요.",
-    "Name" : "이름",
     "Title" : "직위",
     "Company" : "회사",
     "Go to talk conversation" : "Talk 대화로 이동",
@@ -113,37 +126,20 @@ OC.L10N.register(
     "Talk conversations with you" : "나와의 Talk 대화",
     "Calendar events with you" : "나와의 달력 일정",
     "No shared items with this contact" : "이 연락처와 공유된 항목 없음",
-    "This contact is in read-only mode. You do not have permission to edit this contact." : "이 연락처는 읽기 전용 모드입니다. 편집할 수 있는 권한이 없습니다.",
-    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "편집하려고 하는 연락처가 변경되었습니다. 연락처를 직접 새로 고치십시오. 추가 변경 사항은 손실됩니다.",
-    "Address book" : "주소록",
-    "Add contact to Birthday Calendar" : "연락처를 생일 달력에 추가",
-    "Exclude contact from Birthday Calendar" : "생일 달력에서 연락처 제외",
-    "{title} at {organization}" : "{organization}의 {title}",
-    "Syntax error. Cannot open the contact." : "문법 오류입니다. 연락처를 열 수 없습니다.",
-    "The contact does not exist on the server anymore." : "연락처가 서버에 더 이상 존재하지 않습니다.",
-    "Unable to retrieve the contact from the server, please check your network connection." : "연락처를 가져올 수 없습니다. 네트워크 연결을 확인하세요.",
-    "An error occurred while trying to move the contact" : "연락처를 이동하는 중 오류 발생",
-    "An error occurred while trying to copy the contact" : "연락처를 복사하는 중 오류 발생",
-    "Unable to update contact" : "연락처를 갱신할 수 없음",
     "Search contacts …" : "연락처 검색…",
     "Add to {group}" : "{group}에 추가",
     "Remove {type}" : "{type} 삭제",
+    "Add to group" : "그룹에 추가",
     "Search {types}" : "{types} 검색",
     "Search for people to add" : "추가할 사람 검색",
     "No results" : "결과 없음",
-    "Add to group" : "그룹에 추가",
     "Add {type}" : "{type} 추가",
+    "Unable to get the results" : "결과를 받아올 수 없음",
+    "Some members could not be added" : "일부 회원을 추가할 수 없음",
     "Loading members list …" : "회원 목록 불러오는 중 ...",
     "You currently have no access to the member list" : "현재 이 구성원 목록에 접근할 수 없습니다",
     "Add members" : "회원 추가",
     "Add to {circle}" : "{circle}에 추가",
-    "Unable to get the recommendations list" : "추천 목록을 받아올 수 없음",
-    "Unable to get the results" : "결과를 받아올 수 없음",
-    "Some members could not be added" : "일부 회원을 추가할 수 없음",
-    "Accept membership request" : "가입 요청 수락",
-    "Reject membership request" : "가입 요청 거절",
-    "Manage level" : "레벨 관리",
-    "Remove member" : "회원 삭제",
     "Pending" : "보류 중",
     "Promote as sole owner" : "단독 소유 권한 부여",
     "Promote to {level}" : "{level}(으)로 진급",
@@ -151,18 +147,27 @@ OC.L10N.register(
     "Could not delete the member {displayName}" : "{displayName} 회원을 삭제할 수 없습니다.",
     "Could not change the member level to {level}" : "회원 레벨을 {level}로 바꿀 수 없습니다.",
     "Could not accept membership request" : "가입 요쳥을 수락할 수 없습니다",
-    "Chart" : "차트",
+    "Accept membership request" : "가입 요청 수락",
+    "Reject membership request" : "가입 요청 거절",
+    "Manage level" : "레벨 관리",
+    "Remove member" : "회원 삭제",
     "Select chart …" : "차트 선택 ...",
-    "Select type" : "종류 선택",
+    "Chart" : "차트",
     "Select Date" : "날짜 선택",
+    "Select type" : "종류 선택",
     "Add contact in group" : "그룹에 연락처 추가",
     "None" : "없음",
     "Select option" : "옵션 선택",
-    "New contact" : "새 연락처",
     "Unable to create the contact." : "연락처를 만들 수 없습니다.",
     "Contact not found" : "연락처를 찾을 수 없음",
     "Group {group} not found" : "그룹 {group}을(를) 찾을 수 없음",
+    "New contact" : "새 연락처",
+    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} 연락처를 {name}에 추가하는 중"],
+    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["{success} 연락처를 {name}에 추가하는 중"],
+    "_{count} error_::_{count} errors_" : ["{count} 오류 발생"],
     "Close" : "닫기",
+    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["{addressbook}에 %n 연락처를 가져오는 중"],
+    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["{addressbook}에 %n 연락처 가져오기 완료"],
     "Import" : "가져오기",
     "Could not copy" : "복사할 수 없음",
     "You are about to leave {circle}.\nAre you sure?" : "{circle} 서클에서 정말 떠나시겠습니까?",
