@@ -9,9 +9,9 @@ OC.L10N.register(
     "Copy to full name" : "複製到全名",
     "Omit year" : "省略年份",
     "Allow updating avatars from social media" : "允許從社群媒體更新虛擬化身大頭照",
+    "There was an error fetching the member list" : "擷取成員清單出錯",
     "Please select a team" : "請選取團隊",
     "Loading team…" : "正在加載團隊 …",
-    "There was an error fetching the member list" : "擷取成員清單出錯",
     "Loading contacts …" : "正在載入通訊錄 …",
     "There are no contacts yet" : "目前沒有聯絡人",
     "Create contact" : "建立聯絡人",
@@ -32,12 +32,6 @@ OC.L10N.register(
     "Send email" : "傳送電郵",
     "Send email as BCC" : "以 BCC 方式發送電郵",
     "Delete" : "刪除",
-    "Contact groups" : "聯絡群組",
-    "Create a new contact group" : "創建新聯絡人群組",
-    "Contact group name" : "聯絡人群組名稱",
-    "Teams" : "團隊",
-    "Create a new team" : "創建新團隊",
-    "Open the contacts app settings" : "開啟通訊錄應用程式設定",
     "Show all groups" : "顯示所有群組",
     "Collapse groups" : "收合群組",
     "Show all teams" : "顯示所有團隊",
@@ -47,10 +41,13 @@ OC.L10N.register(
     "An error occurred while creating the group" : "建立群組時發生錯誤",
     "This team already exists" : "此團隊已存在",
     "An error happened during the creation of the team" : "建立團隊時發生錯誤",
-    "{addressbookname} (Disabled)" : "{addressbookname}（已停用）",
-    "Download" : "下載",
-    "Show" : "顯示",
-    "Unshare from me" : "取消與我分享",
+    "Contact groups" : "聯絡群組",
+    "Create a new contact group" : "創建新聯絡人群組",
+    "Contact group name" : "聯絡人群組名稱",
+    "Teams" : "團隊",
+    "Create a new team" : "創建新團隊",
+    "Open the contacts app settings" : "開啟通訊錄應用程式設定",
+    "_Shared with {num} entity_::_Shared with {num} entities_" : ["與 {num} 個實體分享"],
     "Copied" : "已複製",
     "Cannot copy" : "無法複製",
     "Copy link" : "複製連結",
@@ -61,23 +58,27 @@ OC.L10N.register(
     "Unshare {addressbook}?" : "取消分享 {addressbook}？",
     "Deletion of address book was not successful." : "刪除通訊錄失敗。",
     "Renaming of address book was not successful." : "重新命名通訊錄失敗。",
+    "{addressbookname} (Disabled)" : "{addressbookname}（已停用）",
+    "Download" : "下載",
+    "Show" : "顯示",
+    "Unshare from me" : "取消與我分享",
     "_%n contact_::_%n contacts_" : ["%n 位聯絡人"],
     "_%n group_::_%n groups_" : ["%n 個群組"],
     "Share with users or groups" : "與用戶或群組分享",
     "Share with users" : "與用戶分享",
     "No users or groups" : "沒有用戶或群組",
-    "can edit" : "允許編輯",
     "Unable to delete the share" : "無法刪除這個分享",
     "Unable to change permissions" : "無法變更權限",
+    "can edit" : "允許編輯",
+    "Choose a vCard file to import" : "選取要導入的 vCard 檔案",
     "Import contacts" : "導入聯絡人",
     "Import into the {addressbookName} address book" : "導入至 {addressbookName} 通訊錄",
     "Select local file" : "選擇本機檔案",
     "Import from files" : "從檔案導入",
     "Importing is disabled because there are no address books available" : "已停用導入，因為沒有可用的通訊錄",
-    "Choose a vCard file to import" : "選取要導入的 vCard 檔案",
+    "An error occurred, unable to create the address book" : "發生錯誤，無法建立通訊錄",
     "Add new address book" : "添加新通訊錄",
     "Add" : "添加",
-    "An error occurred, unable to create the address book" : "發生錯誤，無法建立通訊錄",
     "First name" : "名",
     "Last name" : "姓",
     "Phonetic first name" : "音頻名",
@@ -95,6 +96,10 @@ OC.L10N.register(
     "Save" : "保存",
     "Change unique password" : "更改獨一無二的密碼",
     "Failed to save password. Please try again later." : "保存密碼失敗。請稍後再試。",
+    "There is no description for this team" : "此團隊沒有描述",
+    "Enter a description for the team" : "輸入團隊的描述",
+    "An error happened during description sync" : "描述同步期間發生錯誤",
+    "An error happened during name sync" : "名稱同步期間發生錯誤",
     "Team owned by {owner}" : "{owner} 擁有的團隊",
     "Team settings" : "團隊設定",
     "Request to join" : "請求加入",
@@ -106,19 +111,10 @@ OC.L10N.register(
     "Team name" : "團隊名字",
     "Settings" : "Settings",
     "Actions" : "操作",
-    "There is no description for this team" : "此團隊沒有描述",
-    "Enter a description for the team" : "輸入團隊的描述",
-    "An error happened during description sync" : "描述同步期間發生錯誤",
-    "An error happened during name sync" : "名稱同步期間發生錯誤",
-    "Cancel" : "取消",
     "Confirm" : "確認",
+    "Cancel" : "取消",
     "Add more info" : "添加更多資料",
     "More fields" : "更多欄位",
-    "Crop contact photo" : "裁剪聯絡人照片",
-    "Upload a new picture" : "上傳一張新的圖片",
-    "Choose from Files" : "從檔案選取",
-    "Download picture" : "下載圖片",
-    "Delete picture" : "刪除圖片",
     "Please select a valid format" : "請選擇有效的格式",
     "Invalid image" : "圖像無效",
     "Error cropping picture" : "裁剪圖片時出錯",
@@ -128,9 +124,26 @@ OC.L10N.register(
     "Avatar downloaded from social network" : "從社群網路下載虛擬化身大頭照",
     "Avatar already up to date" : "虛擬化身大頭照已是最新",
     "Avatar download failed" : "虛擬化身大頭照下載失敗",
+    "Crop contact photo" : "裁剪聯絡人照片",
+    "Upload a new picture" : "上傳一張新的圖片",
+    "Choose from Files" : "從檔案選取",
+    "Download picture" : "下載圖片",
+    "Delete picture" : "刪除圖片",
+    "This contact is in read-only mode. You do not have permission to edit this contact." : "此聯絡人處於唯讀模式。您無權編輯此聯絡人。",
+    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "您嘗試編輯的聯絡人已變更。請手動重新整理聯絡人。任何進一步的編輯都會被丟棄。",
+    "Address book" : "通訊錄",
+    "Add contact to Birthday Calendar" : "將聯絡人添加至生日日曆",
+    "Exclude contact from Birthday Calendar" : "從生日日曆中排除聯絡人",
+    "{title} at {organization}" : "{organization} {title}",
+    "Name" : "姓名",
+    "Syntax error. Cannot open the contact." : "語法錯誤。無法開啟聯絡人。",
+    "The contact does not exist on the server anymore." : "伺服器上不再存在該聯絡人。",
+    "Unable to retrieve the contact from the server, please check your network connection." : "無法從伺服器擷取聯絡人，請檢查您的網路連線。",
+    "An error occurred while trying to move the contact" : "嘗試移動聯絡人時發生錯誤",
+    "An error occurred while trying to copy the contact" : "嘗試複製聯絡人時發生錯誤",
+    "Unable to update contact" : "無法更新聯絡人",
     "No contact selected" : "未選擇聯絡人",
     "Select a contact on the list to begin" : "在列表中選擇一個聯絡人以開始",
-    "Name" : "姓名",
     "Title" : "職銜",
     "Company" : "公司名稱",
     "Go to talk conversation" : "前往對話",
@@ -147,25 +160,13 @@ OC.L10N.register(
     "Calendar events with you" : "與您分享的日曆活動",
     "Deck cards with you" : "與您分享的 Deck 卡片",
     "No shared items with this contact" : "沒有與該聯絡人分享的項目",
-    "This contact is in read-only mode. You do not have permission to edit this contact." : "此聯絡人處於唯讀模式。您無權編輯此聯絡人。",
-    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "您嘗試編輯的聯絡人已變更。請手動重新整理聯絡人。任何進一步的編輯都會被丟棄。",
-    "Address book" : "通訊錄",
-    "Add contact to Birthday Calendar" : "將聯絡人添加至生日日曆",
-    "Exclude contact from Birthday Calendar" : "從生日日曆中排除聯絡人",
-    "{title} at {organization}" : "{organization} {title}",
-    "Syntax error. Cannot open the contact." : "語法錯誤。無法開啟聯絡人。",
-    "The contact does not exist on the server anymore." : "伺服器上不再存在該聯絡人。",
-    "Unable to retrieve the contact from the server, please check your network connection." : "無法從伺服器擷取聯絡人，請檢查您的網路連線。",
-    "An error occurred while trying to move the contact" : "嘗試移動聯絡人時發生錯誤",
-    "An error occurred while trying to copy the contact" : "嘗試複製聯絡人時發生錯誤",
-    "Unable to update contact" : "無法更新聯絡人",
     "Search contacts …" : "搜尋聯絡人…",
     "Add to {group}" : "新增至 {group]",
     "Remove {type}" : "移除 {type}",
+    "Add to group" : "新增至群組",
     "Search {types}" : "搜尋 {types}",
     "Search for people to add" : "搜索要添加的人",
     "No results" : "沒有結果",
-    "Add to group" : "新增至群組",
     "Add {type}" : "新增 {type}",
     "New team name" : "新團隊名字",
     "Personal team" : "個人團隊",
@@ -173,20 +174,15 @@ OC.L10N.register(
     "Local team" : "本地團隊",
     "This team will not be shared with the other instances of the global scale" : "此團隊不會與全球範圍內的其他實例共享",
     "Create team" : "創建團隊",
+    "Unable to get the results" : "無法得到結果",
+    "Some members could not be added" : "部分成員無法添加",
+    "There was an issue adding members to the team" : "將成員添加到團隊時出現問題",
     "Team members" : "團隊成員",
     "Loading members list …" : "正在加載成員清單 …",
     "The list of members is only visible to members of this team" : "成員清單僅有此團隊的成員可見",
     "You currently have no access to the member list" : "您目前無權存取會員清單",
     "Add members" : "添加成員",
     "Add to {circle}" : "添加到 {circle}",
-    "Unable to get the recommendations list" : "無法獲取推薦列表",
-    "Unable to get the results" : "無法得到結果",
-    "Some members could not be added" : "部分成員無法添加",
-    "There was an issue adding members to the team" : "將成員添加到團隊時出現問題",
-    "Accept membership request" : "接受會員申請",
-    "Reject membership request" : "拒絕會員申請",
-    "Manage level" : "管理程度",
-    "Remove member" : "移除成員",
     "Pending" : "待定的",
     "Promote as sole owner" : "晉升作為唯一所有者",
     "Promote to {level}" : "晉升到 {level}",
@@ -194,19 +190,28 @@ OC.L10N.register(
     "Could not delete the member {displayName}" : "不能刪除成員 {displayName}",
     "Could not change the member level to {level}" : "無法將成員級別更改為 {level}",
     "Could not accept membership request" : "無法接受成為成員的申請",
-    "Chart" : "圖表",
+    "Accept membership request" : "接受會員申請",
+    "Reject membership request" : "拒絕會員申請",
+    "Manage level" : "管理程度",
+    "Remove member" : "移除成員",
     "Select chart …" : "選擇圖表 ...",
-    "Select type" : "選擇類型",
+    "Chart" : "圖表",
     "Select Date" : "選擇日期",
+    "Select type" : "選擇類型",
     "Add contact in group" : "新增聯絡人到群組",
     "None" : "無",
     "Select option" : "選擇選項",
     "Add property of this type" : "添加此類型的屬性",
-    "New contact" : "新聯絡人",
     "Unable to create the contact." : "無法建立聯絡人",
     "Contact not found" : "找不到聯絡人",
     "Group {group} not found" : "找不到群組 {group}",
+    "New contact" : "新聯絡人",
+    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} 個聯絡人已新增至 {name}"],
+    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["已新增 {success} 個聯絡人至 {name}"],
+    "_{count} error_::_{count} errors_" : ["{count} 個錯誤"],
     "Close" : "關閉",
+    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["正在導入 %n 個聯絡人至 {addressbook}"],
+    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["完成導入 %n 個聯絡人至 {addressbook}"],
     "No data for this contact" : "此聯絡人沒有數據資料",
     "No data for this contact on their profile" : "此聯絡人的個人檔案中沒有數據資料",
     "Import" : "導入",
